@@ -33,7 +33,7 @@ use Excel::Writer::XLSX::Package::XMLwriter;
 use Excel::Writer::XLSX::Utility qw(xl_cell_to_rowcol xl_rowcol_to_cell);
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '0.55';
+our $VERSION = '0.56';
 
 
 ###############################################################################
@@ -381,10 +381,6 @@ sub add_chart {
 
     my $chart = Excel::Writer::XLSX::Chart->factory( $type, $arg{subtype} );
 
-    # Get an incremental id to use for axes ids.
-    my $chart_index = scalar @{ $self->{_charts} };
-    $chart->{_id} = $chart_index;
-
     # If the chart isn't embedded let the workbook control it.
     if ( !$embedded ) {
 
@@ -1424,8 +1420,6 @@ sub _prepare_drawings {
         my $shape_count = scalar @{ $sheet->{_shapes} };
         next unless ( $chart_count + $image_count + $shape_count );
 
-        $sheet->_sort_charts();
-
         $drawing_id++;
 
         for my $index ( 0 .. $chart_count - 1 ) {
@@ -1454,6 +1448,15 @@ sub _prepare_drawings {
         push @{ $self->{_drawings} }, $drawing;
     }
 
+    # Sort the workbook charts references into the order that the were
+    # written from the worksheets above.
+    my @chart_data = @{ $self->{_charts} };
+
+    @chart_data = sort { $a->{_id} <=> $b->{_id} } @chart_data;
+
+    $self->{_charts} = \@chart_data;
+
+
     $self->{_drawing_count} = $drawing_id;
 }
 
@@ -2124,7 +2127,7 @@ sub _write_sheet {
     push @attributes, ( 'r:id' => $r_id );
 
 
-    $self->xml_encoded_empty_tag( 'sheet', @attributes );
+    $self->xml_empty_tag( 'sheet', @attributes );
 }
 
 
